using System.Collections.Generic;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    /// <summary>
    /// Template used to draw a gauge, stores a reference to animations used to draw the gauge, and provides a draw function.
    /// </summary>
    [TypeConverter(typeof(GaugeDrawTemplateConverter))]
    public partial class GaugeDrawTemplate : Class
    {
        #region Members

        private string myBackground, myFill, myLines, myLinesFill, myEndCapRight, myEndCapLeft;

        #endregion

        #region Properties

        /// <summary>
        /// Name of the animation used as the gauge's background.
        /// </summary>
        [XmlElement("Background", IsNullable = false)]
        [Browsable(true), Description("Name of the animation used as the gauge's background.")]
        [NotifyParentProperty(true)]
        public string Background { get { return myBackground; } set { myBackground = value; } }

        /// <summary>
        /// Name of the animation used to fill in the gauge.
        /// </summary>
        [XmlElement("Fill", IsNullable = false)]
        [Browsable(true), Description("Name of the animation used to fill in the gauge.")]
        [NotifyParentProperty(true)]
        public string Fill { get { return myFill; } set { myFill = value; } }

        /// <summary>
        /// Name of the animation used to draw marker lines in the gauge.
        /// </summary>
        [XmlElement("Lines", IsNullable = false)]
        [Browsable(true), Description("Name of teh animation used to draw marker lines in the gauge.")]
        [NotifyParentProperty(true)]
        public string Lines { get { return myLines; } set { myLines = value; } }

        /// <summary>
        /// Name of the animation used to fill in the marker lines in the gauge.
        /// </summary>
        [XmlElement("LinesFill", IsNullable = false)]
        [Browsable(true), Description("Name of the animation used to fill in the marker lines in the gauge.")]
        [NotifyParentProperty(true)]
        public string LinesFill { get { return myLinesFill; } set { myLinesFill = value; } }

        /// <summary>
        /// Name of the animation used to cap off the left edge of the gauge.
        /// </summary>
        [XmlElement("EndCapLeft", IsNullable = false)]
        [Browsable(true), Description("Name of the animation used to cap off the left edge of the gauge.")]
        [NotifyParentProperty(true)]
        public string EndCapLeft { get { return myEndCapLeft; } set { myEndCapLeft = value; } }

        /// <summary>
        /// Name of the animation used to cap off the right edge of the gauge.
        /// </summary>
        [XmlElement("EndCapRight", IsNullable = false)]
        [Browsable(true), Description("Name of the animation used to cap off the right edge of the gauge.")]
        [NotifyParentProperty(true)]
        public string EndCapRight { get { return myEndCapRight; } set { myEndCapRight = value; } }

        #endregion

        #region Creation

        public GaugeDrawTemplate()
            : this(null)
        {
        }

        public GaugeDrawTemplate(EQInterface eqInterface)
            : base(eqInterface)
        {
        }

        #endregion

        #region Deserialization

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            GaugeDrawTemplate temp_GaugeDrawTemplate = obj as GaugeDrawTemplate;
            if (temp_GaugeDrawTemplate != null)
            {
                Background = temp_GaugeDrawTemplate.Background;
                Fill = temp_GaugeDrawTemplate.Fill;
                Lines = temp_GaugeDrawTemplate.Lines;
                LinesFill = temp_GaugeDrawTemplate.LinesFill;
                EndCapLeft = temp_GaugeDrawTemplate.EndCapLeft;
                EndCapRight = temp_GaugeDrawTemplate.EndCapRight;
            }
        }

        #endregion
    }

    public class GaugeDrawTemplateConverter : ExpandableObjectConverter
    {
        public override object ConvertTo(ITypeDescriptorContext context, System.Globalization.CultureInfo culture, object value, System.Type destinationType)
        {
            return (destinationType == typeof(string)) ? string.Empty : base.ConvertTo(context, culture, value, destinationType);
        }
    }
}
